@@ -5,15 +5,16 @@ Note:
 """
 
 import argparse
-from typing import List
+import logging
 
 import moe
 import moe.cli
-from moe import query
-from moe.config import Config
 from moe.plugins import remove as moe_rm
+from moe.query import QueryError, query
 
-__all__: List[str] = []
+__all__: list[str] = []
+
+log = logging.getLogger("moe.cli.remove")
 
 
 @moe.hookimpl
@@ -29,19 +30,23 @@ def add_command(cmd_parsers: argparse._SubParsersAction):
     rm_parser.set_defaults(func=_parse_args)
 
 
-def _parse_args(config: Config, args: argparse.Namespace):
+def _parse_args(args: argparse.Namespace):
     """Parses the given commandline arguments.
 
     Args:
-        config: Configuration in use.
         args: Commandline arguments to parse.
 
     Raises:
-        SystemExit: Query returned no tracks.
+        SystemExit: Invalid query given, or no items to remove.
     """
-    items = query.query(args.query, query_type=args.query_type)
+    try:
+        items = query(args.query, query_type=args.query_type)
+    except QueryError as err:
+        log.error(err)
+        raise SystemExit(1) from err
 
     if not items:
+        log.error("No items found to remove.")
         raise SystemExit(1)
 
     for item in items:
